# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .aquatroll import (
    AquaTrollParameterBlock,
    AquaTrollProbeMetadata,
    AquaTrollSensorMetadata,
    AquaTrollSensorMetadataArray,
    AquaTrollSensorParameters,
    AquaTrollSensorParametersArray,
    SetAquaTrollConnectionStatus,
    SetAquaTrollParameterUnit,
    AquaTrollDevice,
    AquaTrollDeviceStatus,
    AquaTrollParameter,
    AquaTrollQuality,
    AquaTrollSensor,
    AquaTrollSensorStatus,
    AquaTrollUnit,
    Type,
)
from .control import (
    ActivateGuestPortsCtrl,
    ActivateMultibeamCtrl,
    AutoAltitudeCtrl,
    AutoDepthCtrl,
    AutoHeadingCtrl,
    AutoPilotHeaveCtrl,
    AutoPilotSurgeYawCtrl,
    CalibrateDvlGyroCtrl,
    CancelCalibrationCtrl,
    ClearMissionCtrl,
    DeactivateGuestPortsCtrl,
    DeactivateMultibeamCtrl,
    EndDiveCtrl,
    FinishCalibrationCtrl,
    GenericServoCtrl,
    GripperCtrl,
    GuestportLightsCtrl,
    LaserCtrl,
    LightsCtrl,
    MotionInputCtrl,
    MultibeamServoCtrl,
    PauseMissionCtrl,
    PilotGPSPositionCtrl,
    PingerConfigurationCtrl,
    RecordCtrl,
    ResetOdometerCtrl,
    ResetPositionCtrl,
    RestartGuestPortsCtrl,
    RunMissionCtrl,
    SetAquaTrollConnectionStatusCtrl,
    SetAquaTrollParameterUnitCtrl,
    SetMultibeamConfigCtrl,
    StartCalibrationCtrl,
    StartDiveCtrl,
    StationKeepingCtrl,
    SystemTimeCtrl,
    TakePictureCtrl,
    TiltStabilizationCtrl,
    TiltVelocityCtrl,
    WatchdogCtrl,
    WaterDensityCtrl,
    WeatherVaningCtrl,
)
from .message_formats import (
    Altitude,
    Attitude,
    AutoAltitudeState,
    AutoDepthState,
    AutoHeadingState,
    AutoPilotHeaveState,
    AutoPilotSurgeYawState,
    Battery,
    BatteryBQ40Z50,
    BinlogRecord,
    CalibrationState,
    CameraParameters,
    CanisterHumidity,
    CanisterTemperature,
    ClientInfo,
    ConnectedClient,
    ConnectionDuration,
    ControlForce,
    ControllerHealth,
    ControlMode,
    CpProbe,
    CPUInfo,
    CPUTemperature,
    Depth,
    DiveTime,
    DroneInfo,
    DvlTransducer,
    DvlVelocity,
    ErrorFlags,
    ForwardDistance,
    GenericServo,
    GripperVelocities,
    GuestPortConnectorInfo,
    GuestPortCurrent,
    GuestPortDevice,
    GuestPortDeviceList,
    GuestPortInfo,
    GuestPortRestartInfo,
    Imu,
    IperfStatus,
    Laser,
    LatLongPosition,
    Lights,
    MedusaSpectrometerData,
    MotionInput,
    MultibeamConfig,
    MultibeamDiscovery,
    MultibeamFrameOffset,
    MultibeamPing,
    MultibeamServo,
    MutltibeamRecordingIndex,
    NavigationSensorStatus,
    Notification,
    NStreamers,
    OverlayParameters,
    PersistentStorageSettings,
    PingerConfiguration,
    PositionEstimate,
    RecordOn,
    RecordState,
    Reference,
    ResetPositionSettings,
    StationKeepingState,
    StorageSpace,
    SystemTime,
    ThicknessGauge,
    TiltAngle,
    TiltStabilizationState,
    TiltVelocity,
    TimeLapseState,
    Vector3,
    WaterDensity,
    WaterTemperature,
    WeatherVaningState,
    Camera,
    DepthUnit,
    FontSize,
    Framerate,
    GuestPortDetachStatus,
    GuestPortDeviceID,
    GuestPortError,
    GuestPortNumber,
    HeadingSource,
    IntervalType,
    LogoType,
    Model,
    MultibeamFrequencyMode,
    NavigationSensorID,
    NotificationLevel,
    NotificationType,
    PressureSensorType,
    ResetCoordinateSource,
    Resolution,
    TemperatureUnit,
    ThicknessUnit,
)
from .mission_planning import (
    CameraCommand,
    ControlModeCommand,
    DepthSetPoint,
    DepthSetPointCommand,
    GoToHomeCommand,
    GoToSeabedCommand,
    GoToSurfaceCommand,
    Instruction,
    Mission,
    MissionStatus,
    PathSegment,
    ReferenceAutoPilot,
    TiltMainCameraCommand,
    TiltMultibeamCommand,
    WaitForCommand,
    Waypoint,
    WaypointCommand,
    CameraAction,
    ControlModeHorizontal,
    ControlModeVertical,
    DepthZeroReference,
    InstructionType,
    MissionState,
)
from .req_rep import (
    ConnectClientRep,
    ConnectClientReq,
    DisconnectClientRep,
    DisconnectClientReq,
    GetBatteryRep,
    GetBatteryReq,
    GetCameraParametersRep,
    GetCameraParametersReq,
    GetMissionRep,
    GetMissionReq,
    GetOverlayParametersRep,
    GetOverlayParametersReq,
    GetPersistentStorageSettingsRep,
    GetPersistentStorageSettingsReq,
    GetTelemetryRep,
    GetTelemetryReq,
    PingRep,
    PingReq,
    SetCameraParametersRep,
    SetCameraParametersReq,
    SetInstructionUpdateRep,
    SetInstructionUpdateReq,
    SetMissionRep,
    SetMissionReq,
    SetOverlayParametersRep,
    SetOverlayParametersReq,
    SetPersistentStorageSettingsRep,
    SetPersistentStorageSettingsReq,
    SetPubFrequencyRep,
    SetPubFrequencyReq,
    SetThicknessGaugeParametersRep,
    SetThicknessGaugeParametersReq,
    SyncTimeRep,
    SyncTimeReq,
)
from .telemetry import (
    AltitudeTel,
    AquaTrollProbeMetadataTel,
    AquaTrollSensorMetadataTel,
    AquaTrollSensorParametersTel,
    AttitudeTel,
    BatteryBQ40Z50Tel,
    BatteryTel,
    CalibratedImuTel,
    CalibrationStateTel,
    CanisterBottomHumidityTel,
    CanisterBottomTemperatureTel,
    CanisterTopHumidityTel,
    CanisterTopTemperatureTel,
    ConnectedClientsTel,
    ControlForceTel,
    ControllerHealthTel,
    ControlModeTel,
    CpProbeTel,
    CPUInfoTel,
    CPUTemperatureTel,
    DataStorageSpaceTel,
    DepthTel,
    DiveTimeTel,
    DroneInfoTel,
    DroneTimeTel,
    DvlVelocityTel,
    ErrorFlagsTel,
    ForwardDistanceTel,
    GenericServoTel,
    GuestPortCurrentTel,
    GuestPortLightsTel,
    Imu1Tel,
    Imu2Tel,
    IperfTel,
    LaserTel,
    LightsTel,
    MedusaSpectrometerDataTel,
    MissionStatusTel,
    MultibeamConfigTel,
    MultibeamDiscoveryTel,
    MultibeamPingTel,
    MultibeamServoTel,
    NotificationTel,
    NStreamersTel,
    PilotGPSPositionTel,
    PositionEstimateTel,
    RecordStateTel,
    ReferenceAutoPilotTel,
    ReferenceTel,
    ThicknessGaugeTel,
    TiltAngleTel,
    TiltStabilizationTel,
    TimeLapseStateTel,
    VideoStorageSpaceTel,
    WaterTemperatureTel,
)

__all__ = (
    'AquaTrollParameterBlock',
    'AquaTrollProbeMetadata',
    'AquaTrollSensorMetadata',
    'AquaTrollSensorMetadataArray',
    'AquaTrollSensorParameters',
    'AquaTrollSensorParametersArray',
    'SetAquaTrollConnectionStatus',
    'SetAquaTrollParameterUnit',
    'AquaTrollDevice',
    'AquaTrollDeviceStatus',
    'AquaTrollParameter',
    'AquaTrollQuality',
    'AquaTrollSensor',
    'AquaTrollSensorStatus',
    'AquaTrollUnit',
    'Type',
    'ActivateGuestPortsCtrl',
    'ActivateMultibeamCtrl',
    'AutoAltitudeCtrl',
    'AutoDepthCtrl',
    'AutoHeadingCtrl',
    'AutoPilotHeaveCtrl',
    'AutoPilotSurgeYawCtrl',
    'CalibrateDvlGyroCtrl',
    'CancelCalibrationCtrl',
    'ClearMissionCtrl',
    'DeactivateGuestPortsCtrl',
    'DeactivateMultibeamCtrl',
    'EndDiveCtrl',
    'FinishCalibrationCtrl',
    'GenericServoCtrl',
    'GripperCtrl',
    'GuestportLightsCtrl',
    'LaserCtrl',
    'LightsCtrl',
    'MotionInputCtrl',
    'MultibeamServoCtrl',
    'PauseMissionCtrl',
    'PilotGPSPositionCtrl',
    'PingerConfigurationCtrl',
    'RecordCtrl',
    'ResetOdometerCtrl',
    'ResetPositionCtrl',
    'RestartGuestPortsCtrl',
    'RunMissionCtrl',
    'SetAquaTrollConnectionStatusCtrl',
    'SetAquaTrollParameterUnitCtrl',
    'SetMultibeamConfigCtrl',
    'StartCalibrationCtrl',
    'StartDiveCtrl',
    'StationKeepingCtrl',
    'SystemTimeCtrl',
    'TakePictureCtrl',
    'TiltStabilizationCtrl',
    'TiltVelocityCtrl',
    'WatchdogCtrl',
    'WaterDensityCtrl',
    'WeatherVaningCtrl',
    'Altitude',
    'Attitude',
    'AutoAltitudeState',
    'AutoDepthState',
    'AutoHeadingState',
    'AutoPilotHeaveState',
    'AutoPilotSurgeYawState',
    'Battery',
    'BatteryBQ40Z50',
    'BinlogRecord',
    'CalibrationState',
    'CameraParameters',
    'CanisterHumidity',
    'CanisterTemperature',
    'ClientInfo',
    'ConnectedClient',
    'ConnectionDuration',
    'ControlForce',
    'ControllerHealth',
    'ControlMode',
    'CpProbe',
    'CPUInfo',
    'CPUTemperature',
    'Depth',
    'DiveTime',
    'DroneInfo',
    'DvlTransducer',
    'DvlVelocity',
    'ErrorFlags',
    'ForwardDistance',
    'GenericServo',
    'GripperVelocities',
    'GuestPortConnectorInfo',
    'GuestPortCurrent',
    'GuestPortDevice',
    'GuestPortDeviceList',
    'GuestPortInfo',
    'GuestPortRestartInfo',
    'Imu',
    'IperfStatus',
    'Laser',
    'LatLongPosition',
    'Lights',
    'MedusaSpectrometerData',
    'MotionInput',
    'MultibeamConfig',
    'MultibeamDiscovery',
    'MultibeamFrameOffset',
    'MultibeamPing',
    'MultibeamServo',
    'MutltibeamRecordingIndex',
    'NavigationSensorStatus',
    'Notification',
    'NStreamers',
    'OverlayParameters',
    'PersistentStorageSettings',
    'PingerConfiguration',
    'PositionEstimate',
    'RecordOn',
    'RecordState',
    'Reference',
    'ResetPositionSettings',
    'StationKeepingState',
    'StorageSpace',
    'SystemTime',
    'ThicknessGauge',
    'TiltAngle',
    'TiltStabilizationState',
    'TiltVelocity',
    'TimeLapseState',
    'Vector3',
    'WaterDensity',
    'WaterTemperature',
    'WeatherVaningState',
    'Camera',
    'DepthUnit',
    'FontSize',
    'Framerate',
    'GuestPortDetachStatus',
    'GuestPortDeviceID',
    'GuestPortError',
    'GuestPortNumber',
    'HeadingSource',
    'IntervalType',
    'LogoType',
    'Model',
    'MultibeamFrequencyMode',
    'NavigationSensorID',
    'NotificationLevel',
    'NotificationType',
    'PressureSensorType',
    'ResetCoordinateSource',
    'Resolution',
    'TemperatureUnit',
    'ThicknessUnit',
    'CameraCommand',
    'ControlModeCommand',
    'DepthSetPoint',
    'DepthSetPointCommand',
    'GoToHomeCommand',
    'GoToSeabedCommand',
    'GoToSurfaceCommand',
    'Instruction',
    'Mission',
    'MissionStatus',
    'PathSegment',
    'ReferenceAutoPilot',
    'TiltMainCameraCommand',
    'TiltMultibeamCommand',
    'WaitForCommand',
    'Waypoint',
    'WaypointCommand',
    'CameraAction',
    'ControlModeHorizontal',
    'ControlModeVertical',
    'DepthZeroReference',
    'InstructionType',
    'MissionState',
    'ConnectClientRep',
    'ConnectClientReq',
    'DisconnectClientRep',
    'DisconnectClientReq',
    'GetBatteryRep',
    'GetBatteryReq',
    'GetCameraParametersRep',
    'GetCameraParametersReq',
    'GetMissionRep',
    'GetMissionReq',
    'GetOverlayParametersRep',
    'GetOverlayParametersReq',
    'GetPersistentStorageSettingsRep',
    'GetPersistentStorageSettingsReq',
    'GetTelemetryRep',
    'GetTelemetryReq',
    'PingRep',
    'PingReq',
    'SetCameraParametersRep',
    'SetCameraParametersReq',
    'SetInstructionUpdateRep',
    'SetInstructionUpdateReq',
    'SetMissionRep',
    'SetMissionReq',
    'SetOverlayParametersRep',
    'SetOverlayParametersReq',
    'SetPersistentStorageSettingsRep',
    'SetPersistentStorageSettingsReq',
    'SetPubFrequencyRep',
    'SetPubFrequencyReq',
    'SetThicknessGaugeParametersRep',
    'SetThicknessGaugeParametersReq',
    'SyncTimeRep',
    'SyncTimeReq',
    'AltitudeTel',
    'AquaTrollProbeMetadataTel',
    'AquaTrollSensorMetadataTel',
    'AquaTrollSensorParametersTel',
    'AttitudeTel',
    'BatteryBQ40Z50Tel',
    'BatteryTel',
    'CalibratedImuTel',
    'CalibrationStateTel',
    'CanisterBottomHumidityTel',
    'CanisterBottomTemperatureTel',
    'CanisterTopHumidityTel',
    'CanisterTopTemperatureTel',
    'ConnectedClientsTel',
    'ControlForceTel',
    'ControllerHealthTel',
    'ControlModeTel',
    'CpProbeTel',
    'CPUInfoTel',
    'CPUTemperatureTel',
    'DataStorageSpaceTel',
    'DepthTel',
    'DiveTimeTel',
    'DroneInfoTel',
    'DroneTimeTel',
    'DvlVelocityTel',
    'ErrorFlagsTel',
    'ForwardDistanceTel',
    'GenericServoTel',
    'GuestPortCurrentTel',
    'GuestPortLightsTel',
    'Imu1Tel',
    'Imu2Tel',
    'IperfTel',
    'LaserTel',
    'LightsTel',
    'MedusaSpectrometerDataTel',
    'MissionStatusTel',
    'MultibeamConfigTel',
    'MultibeamDiscoveryTel',
    'MultibeamPingTel',
    'MultibeamServoTel',
    'NotificationTel',
    'NStreamersTel',
    'PilotGPSPositionTel',
    'PositionEstimateTel',
    'RecordStateTel',
    'ReferenceAutoPilotTel',
    'ReferenceTel',
    'ThicknessGaugeTel',
    'TiltAngleTel',
    'TiltStabilizationTel',
    'TimeLapseStateTel',
    'VideoStorageSpaceTel',
    'WaterTemperatureTel',
)
